@@ -1676,7 +1676,7 @@ QByteArray K7Zip::K7ZipPrivate::readAndDecodePackedStreams(bool readMainStreamIn
         }
 
         QByteArray inflated;
-        Q_FOREACH (const QByteArray& data, inflatedDatas) {
+        for (const QByteArray& data : qAsConst(inflatedDatas)) {
             inflated.append(data);
         }
 
@@ -2075,7 +2075,7 @@ QByteArray K7Zip::K7ZipPrivate::encodeStream(QVector<quint64> &packSizes, QVecto
 
     //compress data
     QByteArray encodedData;
-    if (header.size() > 0) {
+    if (!header.isEmpty()) {
         QByteArray enc;
         QBuffer inBuffer(&enc);
 
@@ -2113,7 +2113,7 @@ void K7Zip::K7ZipPrivate::writeHeader(quint64 &headerOffset)
 
     // Archive Properties
 
-    if (folders.size() > 0) {
+    if (!folders.isEmpty()) {
         writeByte(kMainStreamsInfo);
         writePackInfo(0, packSizes, packCRCsDefined, packCRCs);
 
@@ -2759,7 +2759,7 @@ bool K7Zip::closeArchive()
 
     //compress data
     QByteArray encodedData;
-    if (d->outData.size() > 0) {
+    if (!d->outData.isEmpty()) {
         QByteArray enc;
         QBuffer inBuffer(&enc);
 
@@ -2893,7 +2893,8 @@ bool K7Zip::doPrepareWriting(const QString &name, const QString &user,
     const KArchiveEntry *entry = parentDir->entry(fileName);
     if (!entry) {
         K7ZipFileEntry *e = new K7ZipFileEntry(this, fileName, perm, mtime, user, group, QString()/*symlink*/, d->outData.size(), 0 /*unknown yet*/, d->outData);
-        parentDir->addEntry(e);
+        if (!parentDir->addEntryV2(e))
+            return false;
         d->m_entryList << e;
         d->m_currentFile = e;
     } else {
@@ -2972,7 +2973,9 @@ bool K7Zip::doWriteSymLink(const QString &name, const QString &target,
     K7ZipFileEntry *e = new K7ZipFileEntry(this, fileName, perm, mtime, user, group, target, 0, 0, nullptr);
     d->outData.append(encodedTarget);
 
-    parentDir->addEntry(e);
+    if (!parentDir->addEntryV2(e))
+        return false;
+
     d->m_entryList << e;
 
     return true;
